@@ -343,12 +343,9 @@ class dyagram:
             autodetect_tries = 0
             while autodetect_tries < 10:
                 try:
-                    print(f"BEFORE GUESSOR")
                     guesser = SSHDetect(**autodetect_netmiko_args)
-                    print("AFTER GUESSOR")
-                    print("BEFORE BEST MATCH")
                     best_match = guesser.autodetect()
-                    print("AFTER BEST MATCH")
+
 
                     return best_match
 
@@ -358,7 +355,6 @@ class dyagram:
                     return None
 
                 except:
-                    print("HIT EXCEPT IN AUTODETECT")
                     if autodetect_tries > 10:
                         tb = self.get_traceback()
                         self.log.info(f"DEVICE: {device} EXCEPTION THROWN IN GET_DEVICE_TYPE: {tb}")
